[23777] trunk

source_changes at macosforge.org source_changes at macosforge.org
Mon Apr 9 12:13:26 PDT 2007


Revision: 23777
          http://trac.macosforge.org/projects/macports/changeset/23777
Author:   mgrimes at macports.org
Date:     2007-04-09 12:13:26 -0700 (Mon, 09 Apr 2007)

Log Message:
-----------
Forward-declare struct winsize as an incomplete type before any of the declarations that use it to ensure it will mean the same thing in every scope.

Modified Paths:
--------------
    trunk/dports/lang/python24/files/patch-Include-pyport.h

Property Changed:
----------------
    trunk/


Property changes on: trunk
___________________________________________________________________
Name: svk:merge
   - 023a8b07-a327-4f20-9012-67c915bb7b7c:/local/branches/updates:21118
023a8b07-a327-4f20-9012-67c915bb7b7c:/local/trunk:21326
40426cdb-d25d-4106-b89a-567fc1e9311f:/local/trunk:22799
a2b01108-8822-4c85-91cd-1541804339d8:/local/macports:20632
b1dfe3f6-5eec-4605-9368-528ffc7f2357:/local/branches/libdnet-maintainer:20898
b1dfe3f6-5eec-4605-9368-528ffc7f2357:/local/branches/p5-app-cli:20923
b1dfe3f6-5eec-4605-9368-528ffc7f2357:/local/branches/p5-list-moreutils:20919
b1dfe3f6-5eec-4605-9368-528ffc7f2357:/local/branches/p5-path-class:20929
b1dfe3f6-5eec-4605-9368-528ffc7f2357:/local/branches/updates:20946
b1dfe3f6-5eec-4605-9368-528ffc7f2357:/local/trunk:20947
d9146071-5dc1-4620-afc7-8ba4e23d31df:/local/trunk:21690
f2dd1c64-7982-4318-98ce-263798263e0a:/local:23893
fd7794eb-1723-4a49-8be4-c69b2a184b6d:/local/trunk:23630
   + 023a8b07-a327-4f20-9012-67c915bb7b7c:/local/branches/updates:21118
023a8b07-a327-4f20-9012-67c915bb7b7c:/local/trunk:21326
40426cdb-d25d-4106-b89a-567fc1e9311f:/local/trunk:22799
a2b01108-8822-4c85-91cd-1541804339d8:/local/macports:20632
b1dfe3f6-5eec-4605-9368-528ffc7f2357:/local/branches/libdnet-maintainer:20898
b1dfe3f6-5eec-4605-9368-528ffc7f2357:/local/branches/p5-app-cli:20923
b1dfe3f6-5eec-4605-9368-528ffc7f2357:/local/branches/p5-list-moreutils:20919
b1dfe3f6-5eec-4605-9368-528ffc7f2357:/local/branches/p5-path-class:20929
b1dfe3f6-5eec-4605-9368-528ffc7f2357:/local/branches/updates:20946
b1dfe3f6-5eec-4605-9368-528ffc7f2357:/local/trunk:20947
d9146071-5dc1-4620-afc7-8ba4e23d31df:/local/trunk:21690
f2dd1c64-7982-4318-98ce-263798263e0a:/local:23893
fd7794eb-1723-4a49-8be4-c69b2a184b6d:/local/trunk:23809

Modified: trunk/dports/lang/python24/files/patch-Include-pyport.h
===================================================================
--- trunk/dports/lang/python24/files/patch-Include-pyport.h	2007-04-09 17:59:42 UTC (rev 23776)
+++ trunk/dports/lang/python24/files/patch-Include-pyport.h	2007-04-09 19:13:26 UTC (rev 23777)
@@ -1,28 +1,34 @@
-*** Include/pyport.h	Mon May 16 21:36:35 2005
---- Include/pyport.h	Mon May 16 21:47:28 2005
-***************
-*** 152,162 ****
---- 152,174 ----
-  #if defined(PYOS_OS2) && defined(PYCC_GCC)
-  #include <sys/types.h>
-  #endif
-+ 
-+ #if (defined __APPLE__) && (!defined _POSIX_C_SOURCE)
-+ #define TEMPORARILY_DEFINING__POSIX_C_SOURCE    /* so we can #undef it later */
-+ #define _POSIX_C_SOURCE   /* avoid deprecated struct ostat in sys/stat.h */
-+ #endif
-+ 
-  #include <sys/stat.h>
-  #elif defined(HAVE_STAT_H)
-  #include <stat.h>
-  #endif
-  
-+ /* Mac OS X: undefine _POSIX_C_SOURCE if it wasn't defined before */
-+ #ifdef TEMPORARILY_DEFINING__POSIX_C_SOURCE
-+ #undef _POSIX_C_SOURCE
-+ #undef TEMPORARILY_DEFINING__POSIX_C_SOURCE
-+ #endif
-+ 
-  #if defined(PYCC_VACPP)
-  /* VisualAge C/C++ Failed to Define MountType Field in sys/stat.h */
-  #define S_IFMT (S_IFDIR|S_IFCHR|S_IFREG)
+--- Include/pyport.h.orig	2007-03-12 23:26:06.000000000 -0700
++++ Include/pyport.h	2007-03-12 23:29:35.000000000 -0700
+@@ -152,11 +152,23 @@ typedef PY_LONG_LONG		Py_intptr_t;
+ #if defined(PYOS_OS2) && defined(PYCC_GCC)
+ #include <sys/types.h>
+ #endif
++
++#if (defined __APPLE__) && (!defined _POSIX_C_SOURCE)
++#define TEMPORARILY_DEFINING__POSIX_C_SOURCE    /* so we can #undef it later */
++#define _POSIX_C_SOURCE   /* avoid deprecated struct ostat in sys/stat.h */
++#endif
++
+ #include <sys/stat.h>
+ #elif defined(HAVE_STAT_H)
+ #include <stat.h>
+ #endif
+ 
++/* Mac OS X: undefine _POSIX_C_SOURCE if it wasn't defined before */
++#ifdef TEMPORARILY_DEFINING__POSIX_C_SOURCE
++#undef _POSIX_C_SOURCE
++#undef TEMPORARILY_DEFINING__POSIX_C_SOURCE
++#endif
++
+ #if defined(PYCC_VACPP)
+ /* VisualAge C/C++ Failed to Define MountType Field in sys/stat.h */
+ #define S_IFMT (S_IFDIR|S_IFCHR|S_IFREG)
+@@ -393,6 +405,7 @@ extern char * _getpty(int *, int, mode_t
+ /* BSDI does not supply a prototype for the 'openpty' and 'forkpty'
+    functions, even though they are included in libutil. */
+ #include <termios.h>
++struct winsize;
+ extern int openpty(int *, int *, char *, struct termios *, struct winsize *);
+ extern int forkpty(int *, char *, struct termios *, struct winsize *);
+ #endif /* !defined(HAVE_PTY_H) && !defined(HAVE_LIBUTIL_H) */

-------------- next part --------------
An HTML attachment was scrubbed...
URL: http://lists.macosforge.org/pipermail/macports-changes/attachments/20070409/5e1cc18c/attachment.html


More information about the macports-changes mailing list